@@ -6,7 +6,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use Carp;
 use YAML;
 
-$VERSION   = 0.01;
+$VERSION   = 0.02;
 @EXPORT    = qw();
 @EXPORT_OK = qw(zones table);
 %EXPORT_TAGS = ("ALL" => [@EXPORT_OK]);
@@ -16,8 +16,8 @@ sub zones {
       0 => [ qw(NL) ],
       1 => [ qw(BE LU) ],
       2 => [ qw(DK DE FR IT AT ES GB SE) ],
-      3 => [ qw(EE FI HU IE LV LT PL PT SI SK CZ) ],
-      4 => [ qw(AL AD BA BG CY FO GI GR GL IS HR LI MK MT MD ME NO UA RO SM RS 
+      3 => [ qw(BG EE FI HU IE LV LT PL PT RO SI SK CZ) ],
+      4 => [ qw(AL AD BA CY FO GI GL IS HR LI MK MD ME NO UA SM RS 
                 TR VA RU CH) ],
    );
    my %z;
@@ -45,12 +45,12 @@ netherlands:
       '500,1999': 2.64
       '2000,3000': 2.64
     machine:
-      '0,19': 0.43
-      '20,49': 0.78
-      '50,99': 1.13
-      '100,249': 1.48
-      '250,499': 1.88
-      '500,2000': 2.22
+      '0,19': 0.42
+      '20,49': 0.75
+      '50,99': 1.08
+      '100,249': 1.41
+      '250,499': 1.81
+      '500,2000': 2.15
   # Parcels (paketten)
   large:
     stamp: 
@@ -60,13 +60,11 @@ netherlands:
   # Register (aangetekend)
   register:
     stamp:
-      '0,999': 6.45
-      '1000,4999': 7.00
-      '5000,10000': 8.70
+      '0,4999': 6.65
+      '5000,10000': 8.95
     machine:
-      '0,999': 6.25
-      '1000,4999': 6.80
-      '5000,10000': 8.50
+      '0,4999': 6.45
+      '5000,10000': 8.75
 # Outside of the Netherlands
 world:
   basic:
@@ -75,105 +73,93 @@ world:
       # Letters (brievenbuspost)
       small:
         priority:
-          '0,19': 0.72
-          '20,49': 1.44
-          '50,99': 2.16
-          '100,249': 2.88
-          '250,499': 5.48
-          '500,999': 8.64
-          '1000,2000': 10.80
+          '0,19': 0.75
+          '20,49': 1.50
+          '50,99': 2.25
+          '100,249': 3.00
+          '250,499': 6.00
+          '500,2000': 9.00
         standard: 
-          '0,19': 0.67
-          '20,49': 1.21
-          '50,99': 1.76
-          '100,249': 2.45
-          '250,499': 4.02
-          '500,999': 6.47
-          '1000,2000': 8.04
+          '0,19': 0.70
+          '20,49': 1.40
+          '50,99': 2.10
+          '100,249': 2.80
+          '250,499': 4.20
+          '500,2000': 7.00
       # Internationaal Pakket Basis
       large:
         priority:
-          '0,249': 4.10
-          '250,499': 5.70
-          '500,2000': 11.00
+          '0,499': 5.25
+          '500,2000': 11.25
         standard: 
-          '0,249': 3.25
-          '250,499': 4.25
-          '500,2000': 8.00
+          '0,449': 4.20
+          '500,2000': 9.10
     # Outside Europe
     world: 
       # Letters (brievenbuspost)
       small:
         priority:
-          '0,19': 0.89
-          '20,49': 1.78
-          '50,99': 2.67
-          '100,249': 5.34
-          '250,499': 10.68
-          '500,999': 20.47
-          '1000,2000': 21.36
+          '0,19': 0.92
+          '20,49': 1.84
+          '50,99': 2.76
+          '100,249': 5.52
+          '250,499': 10.12
+          '500,2000': 19.32
       # Internationaal Pakket Basis
       large:
         priority:
-          '0,249': 7.00
-          '250,499': 11.00
-          '500,2000': 21.50
+          '0,499': 9.00
+          '500,2000': 19.50
         standard: 
-          '0,249': 4.70
-          '250,499': 8.00
-          '500,2000': 13.50
+          '0,499': 7.00
+          '500,2000': 17.50
   # Internationaal Pakket Plus (Track&Trace)
   plus: 
     zone:
       1: 
-        '0,1999': 11.45
-        '2000,4999': 16.45
-        '5000,9999': 20.95
-        '10000,19999': 27.95
-        '20000,30000': 33.26
+        '0,1999': 11.75
+        '2000,4999': 16.95
+        '5000,9999': 21.45
+        '10000,19999': 28.75
+        '20000,30000': 34.21
       2: 
-        '0,1999': 12.45
-        '2000,4999': 18.45
-        '5000,9999': 23.95
-        '10000,19999': 32.45
-        '20000,30000': 38.62
+        '0,1999': 12.75
+        '2000,4999': 18.95
+        '5000,9999': 24.75
+        '10000,19999': 33.25
+        '20000,30000': 39.57
       3: 
-        '0,1999': 17.45
-        '2000,4999': 22.45
-        '5000,9999': 28.45
-        '10000,19999': 36.95
-        '20000,30000': 43.97
+        '0,1999': 17.95
+        '2000,4999': 23.25
+        '5000,9999': 29.25
+        '10000,19999': 37.95
+        '20000,30000': 45.16
       4: 
-        '0,1999': 17.45
-        '2000,4999': 22.25
-        '5000,9999': 28.95
-        '10000,20000': 38.45
+        '0,1999': 17.95
+        '2000,4999': 23.75
+        '5000,9999': 29.75
+        '10000,20000': 39.25
       # Outside of Europe, Priority/Economy allowed
       5: 
         priority: 
-          '0,1999': 22.45
-          '2000,4999': 31.45
-          '5000,9999': 52.95
-          '10000,20000': 98.45
+          '0,1999': 22.95
+          '2000,4999': 32.45
+          '5000,9999': 54.45
+          '10000,20000': 99.95
         economy: 
-          '0,1999': 17.95
-          '2000,4999': 22.95
-          '5000,9999': 34.95
-          '10000,20000': 53.45
+          '0,1999': 18.45
+          '2000,4999': 24.45
+          '5000,9999': 36.95
+          '10000,20000': 54.95
   # Register ("aangetekend")
   register:
     europe:
-      '0,99': 7.10
-      '100,249': 7.10
-      '250,499': 8.30
-      '500,999': 11.00
-      '1000,2000': 11.75
+      '0,499': 7.50
+      '500,2000': 12.00
     world:
-      '0,99': 7.40
-      '100,249': 8.95
-      '250,499': 14.20
-      '500,999': 22.05
-      '1000,2000': 22.25
+      '0,99': 9.00
+      '100,449': 10.50
+      '500,2000': 21.00
 ...
    return $table;
 }
